@@ -22,7 +22,7 @@ Djimeu, E. W., & Houndolo, D.-G. (2016). "Power Calculation for Causal Inference
 
 import warnings
 from dataclasses import dataclass, field
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Tuple
 
 import numpy as np
 import pandas as pd
